@@ -28,7 +28,7 @@ except ImportError:
 
 __title__ = "vault2vault"
 __summary__ = "Recursively rekey ansible-vault encrypted files and in-line variables"
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __url__ = "https://github.com/enpaul/vault2vault/"
 __license__ = "MIT"
 __authors__ = ["Ethan Paul <24588726+enpaul@users.noreply.github.com>"]
@@ -369,7 +369,7 @@ def _load_password(
 
     if fpath:
         try:
-            with Path(fpath).resolve().open("rb", encoding="utf-8") as infile:
+            with Path(fpath).resolve().open("rb") as infile:
                 return VaultSecret(infile.read())
         except (FileNotFoundError, PermissionError) as err:
             raise RuntimeError(
